utils.specutils_hasp package
============================

haspspectrum
---------------------------------------

.. automodule:: utils.specutils_hasp.haspspectrum
    :members:
    :undoc-members:
    :show-inheritance:

plotspec
-----------------------------------

.. autofunction:: utils.specutils_hasp.plotspec

readspec
-----------------------------------

.. autofunction:: utils.specutils_hasp.readspec
